function [hdrImg] = ldr_to_hdr(ldrImgs, exposures, bits_max)
%LDR_TO_HDR Generate an HDR image from a sequence of LDR images.
%   Generate a hdr image from a sequence of ldr images. Camera response 
%   function is saved in response_function.mat and applied through
%   inverse_res_fct.m. Weights are applied through weight.m.
%       ldrImgs   - sequence of ldr images
%       exposures - exposures corresponding to each image
%       bits_max  - max bits for the hdr image (e.g. 16 or 32)
    
% scale min max bit for output
bits_min          = 0;
[resx, resy, cnt] = size(ldrImgs);
% hdr image
hdrImg = double(zeros(resx, resy));
% total weight
twgt = double(zeros(resx, resy));
% scale images, else the inverse camera response fct yields inf
ldrImgs = ldrImgs ./ bits_max;

% generate sums through hdr algorithm
for j=1:cnt            
    % weight image
    wgt    = weight(double(ldrImgs(:, :, j)));
    % apply inverse camera response function
    rev    = inverse_res_fct(double(ldrImgs(:, :, j)));
    % sum up
    hdrImg = hdrImg + wgt .* rev ./ exposures(j);
    % remember weight
    twgt   = twgt + wgt;
end

% final weight
wgt_not_zero          = twgt ~= 0;
hdrImg(wgt_not_zero)  = hdrImg(wgt_not_zero) ./ twgt(wgt_not_zero);
hdrImg(~wgt_not_zero) = 0;

% scale image min/max to smin/smax
img_min     = min(hdrImg(:));
img_max     = max(hdrImg(:));
scaled_hdri = bits_min + (hdrImg-img_min).*(bits_max-bits_min)./(img_max-img_min);

% output
hdrImg = scaled_hdri;

end

